@@ -34,6 +34,7 @@ from .paginator import (
     ListUsersPaginator,
 )
 from .type_defs import (
+    AssociateUserToPermissionGroupResponseTypeDef,
     CreateChangesetResponseTypeDef,
     CreateDatasetResponseTypeDef,
     CreateDataViewResponseTypeDef,
@@ -44,17 +45,22 @@ from .type_defs import (
     DeleteDatasetResponseTypeDef,
     DeletePermissionGroupResponseTypeDef,
     DisableUserResponseTypeDef,
+    DisassociateUserFromPermissionGroupResponseTypeDef,
     EnableUserResponseTypeDef,
     GetChangesetResponseTypeDef,
     GetDatasetResponseTypeDef,
     GetDataViewResponseTypeDef,
+    GetExternalDataViewAccessDetailsResponseTypeDef,
+    GetPermissionGroupResponseTypeDef,
     GetProgrammaticAccessCredentialsResponseTypeDef,
     GetUserResponseTypeDef,
     GetWorkingLocationResponseTypeDef,
     ListChangesetsResponseTypeDef,
     ListDatasetsResponseTypeDef,
     ListDataViewsResponseTypeDef,
+    ListPermissionGroupsByUserResponseTypeDef,
     ListPermissionGroupsResponseTypeDef,
+    ListUsersByPermissionGroupResponseTypeDef,
     ListUsersResponseTypeDef,
     PermissionGroupParamsTypeDef,
     ResetUserPasswordResponseTypeDef,
@@ -110,6 +116,17 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#exceptions)
         """
 
+    def associate_user_to_permission_group(
+        self, *, permissionGroupId: str, userId: str, clientToken: str = ...
+    ) -> AssociateUserToPermissionGroupResponseTypeDef:
+        """
+        Adds a user account to a permission group to grant permissions for actions a
+        user can perform in FinSpace.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.associate_user_to_permission_group)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#associate_user_to_permission_group)
+        """
+
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
@@ -118,6 +135,14 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#close)
+        """
+
     def create_changeset(
         self,
         *,
@@ -233,6 +258,16 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#disable_user)
         """
 
+    def disassociate_user_from_permission_group(
+        self, *, permissionGroupId: str, userId: str, clientToken: str = ...
+    ) -> DisassociateUserFromPermissionGroupResponseTypeDef:
+        """
+        Removes a user account from a permission group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.disassociate_user_from_permission_group)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#disassociate_user_from_permission_group)
+        """
+
     def enable_user(self, *, userId: str, clientToken: str = ...) -> EnableUserResponseTypeDef:
         """
         Allows the specified user to access the FinSpace web application and API.
@@ -279,6 +314,24 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#get_dataset)
         """
 
+    def get_external_data_view_access_details(
+        self, *, dataViewId: str, datasetId: str
+    ) -> GetExternalDataViewAccessDetailsResponseTypeDef:
+        """
+        Returns the credentials to access the external Dataview from an S3 location.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.get_external_data_view_access_details)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#get_external_data_view_access_details)
+        """
+
+    def get_permission_group(self, *, permissionGroupId: str) -> GetPermissionGroupResponseTypeDef:
+        """
+        Retrieves the details of a specific permission group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.get_permission_group)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#get_permission_group)
+        """
+
     def get_programmatic_access_credentials(
         self, *, environmentId: str, durationInMinutes: int = ...
     ) -> GetProgrammaticAccessCredentialsResponseTypeDef:
@@ -348,6 +401,17 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#list_permission_groups)
         """
 
+    def list_permission_groups_by_user(
+        self, *, userId: str, maxResults: int, nextToken: str = ...
+    ) -> ListPermissionGroupsByUserResponseTypeDef:
+        """
+        Lists all the permission groups that are associated with a specific user
+        account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.list_permission_groups_by_user)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#list_permission_groups_by_user)
+        """
+
     def list_users(self, *, maxResults: int, nextToken: str = ...) -> ListUsersResponseTypeDef:
         """
         Lists all available user accounts in FinSpace.
@@ -356,6 +420,16 @@ class FinSpaceDataClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#list_users)
         """
 
+    def list_users_by_permission_group(
+        self, *, permissionGroupId: str, maxResults: int, nextToken: str = ...
+    ) -> ListUsersByPermissionGroupResponseTypeDef:
+        """
+        Lists details of all the users in a specific permission group.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/finspace-data.html#FinSpaceData.Client.list_users_by_permission_group)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client/#list_users_by_permission_group)
+        """
+
     def reset_user_password(
         self, *, userId: str, clientToken: str = ...
     ) -> ResetUserPasswordResponseTypeDef:
